#include "stat.ih"

Stat::Stat()
:
    d_errno(false)
{}
